package org.eclipse.equinox.launcher;

import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;

public class MultiInputStream extends FilterInputStream {
   private ByteArrayBuffer buffer;

   public MultiInputStream(InputStream in) {
      super(in);
   }

   protected ByteArrayBuffer getBuffer() {
      if (this.buffer == null) {
         this.buffer = new ByteArrayBuffer();
      }

      return this.buffer;
   }

   public synchronized int read() throws IOException {
      ByteArrayBuffer buffer = this.getBuffer();
      if (buffer.size() > 0) {
         int value = buffer.getByteArray()[0];
         buffer.consumed(1);
         return value;
      } else {
         return super.read();
      }
   }

   public synchronized int read(byte[] b, int off, int len) throws IOException {
      ByteArrayBuffer buffer = this.getBuffer();
      if (buffer.size() > 0) {
         int count = Math.min(buffer.size(), len);
         System.arraycopy(buffer.getByteArray(), 0, b, off, count);
         buffer.consumed(count);
         return count;
      } else {
         return super.read(b, off, len);
      }
   }

   public synchronized void sendMessage(String message) {
      try {
         System.out.print(message);
         this.getBuffer().write(message.getBytes());
      } catch (IOException var2) {
      }

   }

   public int available() throws IOException {
      return super.available() + this.getBuffer().size();
   }
}
